
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.8',
    'branch_nick': 'patch-0-Release__1_21_8_preparation',
    'revision_id': 'b717b23f7c9ddd9afaa9862026289326aa68b8d5',
    'revno': 9139
}
